@@ -196,16 +196,16 @@ def transfer(
             raise UserError(
                 format(e).replace("__init__", protocol.__module__)
             ) from None
-        for pw_arg in protocol_instance.required_password_args():
-            if protocol_args.get(pw_arg) is None:
-                setattr(
-                    protocol_instance,
-                    pw_arg,
-                    get_passphrase_from_cmd_or_prompt(
-                        f"Please enter the password for the argument `{pw_arg}`:",
-                        passphrase_cmd,
-                    ),
-                )
+    for pw_arg in protocol_instance.required_password_args():
+        if getattr(protocol_instance, pw_arg, None) is None:
+            setattr(
+                protocol_instance,
+                pw_arg,
+                get_passphrase_from_cmd_or_prompt(
+                    f"Please enter the secret for the argument `{pw_arg}`:",
+                    passphrase_cmd,
+                ),
+            )
     workflows_transfer(
         files,
         protocol=protocol_instance,
