@@ -6,14 +6,14 @@ from ..utils.progress import ProgressInterface
 
 
 class CliProgress(ProgressInterface):
-    """Terminal progress bar
+    """Terminal progress bar.
 
     :param prefix: prefix string (Optional)
     :param suffix: suffix string (Optional)
     :param decimals: positive number of decimals in percent complete
     :param bar_length: character length of bar
     :param fill: Fill character for the bar
-    :param initial_print: If true, do an intial print at :intital_fraction:
+    :param initial_print: If true, do an initial print at :intital_fraction:
     :param initial_fraction: The initial position, the progress bar will start at
     """
 
@@ -58,7 +58,7 @@ class CliProgress(ProgressInterface):
     def get_completed_fraction(self) -> float:
         return self.n
 
-    def print_current(self):
+    def print_current(self) -> None:
         percent = ("{0:." + str(self.decimals) + "f}").format(
             100 * (self.n / float(self.total))
         )
@@ -93,6 +93,9 @@ class CliProgress(ProgressInterface):
 
 
 def format_eta(eta_secs: float) -> str:
+    """Convert an ETA (estimated time of arrival) from a number of seconds to
+    a human-readable string representation of type hh:mm:ss.
+    """
     eta_h, eta_secs = divmod(eta_secs, 3600)
     eta_min, eta_secs = divmod(eta_secs, 60)
     if eta_h != 0.0:
