@@ -1,11 +1,16 @@
 import os
 import urllib
 import urllib.request
+from http.client import HTTPResponse
+from typing import Tuple, Union, Callable
 
 from .error import UserError
 
 
-def build_opener(default_opener=urllib.request.urlopen):
+UrlOpener = Callable[..., HTTPResponse]
+
+
+def build_opener(default_opener: UrlOpener = urllib.request.urlopen) -> UrlOpener:
     proxy_env = os.environ.get("HTTPS_PROXY") or os.environ.get("ALL_PROXY")
     if proxy_env is not None and proxy_env.startswith("socks"):
         protocol, host, port = proxy_env.split(":")
@@ -13,14 +18,16 @@ def build_opener(default_opener=urllib.request.urlopen):
     return default_opener
 
 
-def socks_opener(proxy_settings):
+def socks_opener(proxy_settings: Tuple[str, str, int]) -> UrlOpener:
     """Returns an opener based on proxy settings: Normal opener if no proxy
     settings are given, PySocks opener if proxy settings are given
     """
     return urllib.request.build_opener(socks_handler(*proxy_settings)).open
 
 
-def socks_handler(protocol, host, port):
+def socks_handler(
+    protocol: str, host: str, port: int
+) -> Union[urllib.request.HTTPSHandler, urllib.request.HTTPHandler]:
     try:
         import socks  # pylint: disable=import-outside-toplevel
 
@@ -37,7 +44,10 @@ def socks_handler(protocol, host, port):
         protocol = protocol_mapping[protocol]
     except KeyError:
         raise UserError("Invalid scheme " + protocol) from None
-    return SocksiPyHandler(protocol, host, port)
+    handler: Union[
+        urllib.request.HTTPSHandler, urllib.request.HTTPHandler
+    ] = SocksiPyHandler(protocol, host, port)
+    return handler
 
 
 urlopen = build_opener()
