@@ -1,6 +1,17 @@
 from functools import partial
 from pathlib import Path
-from typing import Callable, Optional, Tuple, Sequence, Dict, Union, Any, cast
+from typing import (
+    Callable,
+    Optional,
+    Tuple,
+    Sequence,
+    Dict,
+    Union,
+    Any,
+    cast,
+    TypeVar,
+    Type,
+)
 
 from .model import AppData
 from .parallel import run_thread
@@ -61,7 +72,7 @@ class SelectionButton(QtWidgets.QPushButton):
         super().__init__(label)
         self.setEnabled(False)
         self._selection_model = selection_model
-        selection_model.selectionChanged.connect(self.selection_changed)
+        selection_model.selectionChanged.connect(self.selection_changed)  # type: ignore
 
     def selection_changed(self) -> None:
         # Following works better than using 'QItemSelection', especially in
@@ -80,7 +91,7 @@ class SelectionAction(QAction):
         super().__init__(*args)
         self.setEnabled(False)
         self._selection_model = selection_model
-        selection_model.selectionChanged.connect(self.selection_changed)
+        selection_model.selectionChanged.connect(self.selection_changed)  # type: ignore
 
     def selection_changed(self) -> None:
         # Following works better than using 'QItemSelection', especially in
@@ -117,7 +128,7 @@ class ConsoleWidget(QtWidgets.QGroupBox):
             QtGui.QIcon(":icon/feather/slash.png"), ""
         )
         btn_clear_console.setToolTip("Clear console")
-        btn_clear_console.clicked.connect(self.clear)
+        btn_clear_console.clicked.connect(self.clear)  # type: ignore
         layout = QtWidgets.QHBoxLayout(self)
         layout.addWidget(self.textbox)
         layout.addWidget(
@@ -145,27 +156,30 @@ class PathInput(QtWidgets.QWidget):
         **kwargs: Any,
     ):
         super().__init__(*args, **kwargs)
-        self.text = LineEdit(self.parent())
+        # Note: cast() is used here because self.parent() wrongly hints that
+        # it returns a QtCore.QObject object.
+        self.parent_widget = cast(QtWidgets.QWidget, self.parent())
+        self.text = LineEdit(self.parent_widget)
         self.text.setReadOnly(True)
         self.btn = QtWidgets.QPushButton(
             QtGui.QIcon(f":icon/feather/{'folder' if directory else 'file'}.png"),
             "",
         )
         self.btn.setToolTip("Change location")
-        self.btn.clicked.connect(partial(self._update_location, directory))
+        self.btn.clicked.connect(partial(self._update_location, directory))  # type: ignore
 
         # Add additional button to allow clearing the selected path.
         self.btn_clear = QtWidgets.QPushButton(
             QtGui.QIcon(":icon/feather/slash.png"), ""
         )
         self.btn_clear.setToolTip("Clear location")
-        self.btn_clear.clicked.connect(self._clear_location)
+        self.btn_clear.clicked.connect(self._clear_location)  # type: ignore
         self.update_path(path)
 
     def update_path(self, path: Optional[Path]) -> None:
         self.path = path
         self.text.setText("" if path is None else str(path))
-        self.text.editingFinished.emit()
+        self.text.editingFinished.emit()  # type: ignore
 
     def _update_location(self, directory: bool) -> None:
         if self.path and self.path.exists():
@@ -174,11 +188,11 @@ class PathInput(QtWidgets.QWidget):
             location = Path.home()
         if directory:
             new_path = QtWidgets.QFileDialog.getExistingDirectory(
-                parent=self.parent(), caption="Select Directory", dir=str(location)
+                parent=self.parent_widget, caption="Select Directory", dir=str(location)
             )
         else:
             new_path, _ = QtWidgets.QFileDialog.getOpenFileName(
-                parent=self.parent(), caption="Select File", dir=str(location)
+                parent=self.parent_widget, caption="Select File", dir=str(location)
             )
         if new_path:
             self.update_path(Path(new_path))
@@ -191,7 +205,7 @@ class PathInput(QtWidgets.QWidget):
 
     def on_path_change(self, fn: Callable[[Optional[Path]], None]) -> None:
         """Run callback when path changes."""
-        self.text.editingFinished.connect(lambda: fn(self.path))
+        self.text.editingFinished.connect(lambda: fn(self.path))  # type: ignore
 
 
 class TabMixin(QtWidgets.QWidget):
@@ -228,14 +242,14 @@ class TabMixin(QtWidgets.QWidget):
 
         # On pressed button, make sure that the focus switches to that
         # button (Mac specific issue)
-        self.btn_test.pressed.connect(self.btn_test.setFocus)
-        self.btn_test.clicked.connect(partial(action, dry_run=True))
+        self.btn_test.pressed.connect(self.btn_test.setFocus)  # type: ignore
+        self.btn_test.clicked.connect(partial(action, dry_run=True))  # type: ignore
         self.btn_run = TabMixin._create_disabled_button(action_name)
 
         # On pressed button, make sure that the focus switches to that
         # button (Mac specific issue)
-        self.btn_run.pressed.connect(self.btn_run.setFocus)
-        self.btn_run.clicked.connect(action)
+        self.btn_run.pressed.connect(self.btn_run.setFocus)  # type: ignore
+        self.btn_run.clicked.connect(action)  # type: ignore
         hbox_layout(self.btn_test, self.btn_run, parent=self.run_panel)
 
     def run_workflow_thread(self, f: Callable[..., Any], **kwargs: Any) -> None:
@@ -257,10 +271,10 @@ def get_text_input(
     buttons = QtWidgets.QDialogButtonBox(QtWidgets.QDialogButtonBox.Cancel)
     ok_btn = buttons.addButton(QtWidgets.QDialogButtonBox.Ok)
     ok_btn.setEnabled(False)
-    buttons.accepted.connect(dialog.accept)
-    buttons.rejected.connect(dialog.reject)
+    buttons.accepted.connect(dialog.accept)  # type: ignore
+    buttons.rejected.connect(dialog.reject)  # type: ignore
     user_input = LineEdit()
-    user_input.textChanged.connect(lambda t: ok_btn.setEnabled(bool(t)))
+    user_input.textChanged.connect(lambda t: ok_btn.setEnabled(bool(t)))  # type: ignore
     if password:
         user_input.setEchoMode(QtWidgets.QLineEdit.EchoMode.Password)
     vbox_layout(QtWidgets.QLabel(msg), user_input, buttons, parent=dialog)
@@ -315,7 +329,7 @@ def create_verify_dtr_checkbox(
         verify_dtr.setStatusTip(
             "Verifying Transfer Request ID in offline mode is not possible."
         )
-    verify_dtr.stateChanged.connect(
+    verify_dtr.stateChanged.connect(  # type: ignore
         lambda state: setattr(app_data, field_name, state == QtCore.Qt.Checked)
     )
     return verify_dtr
@@ -330,7 +344,7 @@ def create_verify_filename_checkbox(
         "naming convention."
     )
     verify_filename.setChecked(app_data.config.verify_package_name)
-    verify_filename.stateChanged.connect(
+    verify_filename.stateChanged.connect(  # type: ignore
         lambda state: setattr(app_data, field_name, state == QtCore.Qt.Checked)
     )
     return verify_filename
@@ -360,17 +374,20 @@ def create_slider(
     def update_text(value: int) -> None:
         widget_value.setText(str(value))
 
-    slider.valueChanged.connect(update_text)
+    slider.valueChanged.connect(update_text)  # type: ignore
     if on_change is not None:
-        slider.valueChanged.connect(on_change)
+        slider.valueChanged.connect(on_change)  # type: ignore
 
     return slider, widget_value
 
 
+WIDGET_OR_LAYOUT = Union[QtWidgets.QWidget, QtWidgets.QBoxLayout]
+
+
 class GridLayoutCell:
     def __init__(
         self,
-        widget: QtWidgets.QWidget,
+        widget: WIDGET_OR_LAYOUT,
         span: int = 1,
         align: Optional[QtCore.Qt.AlignmentFlag] = None,
     ):
@@ -380,17 +397,16 @@ class GridLayoutCell:
 
 
 def layout_add(
-    layout: QtWidgets.QLayout, child: Union[QtWidgets.QWidget, QtWidgets.QLayout]
-) -> Callable[..., Any]:
+    layout: Union[QtWidgets.QGridLayout, QtWidgets.QBoxLayout],
+    child: WIDGET_OR_LAYOUT,
+) -> Callable[..., None]:
     """Returns either layout.addLayout or layout.addWidget depending on the
     type of child.
     """
-    add_layout_function: Callable[..., Any] = layout.addLayout
-    add_widget_function: Callable[..., Any] = layout.addWidget
     return (
-        add_layout_function
+        layout.addLayout
         if isinstance(child, (QtWidgets.QVBoxLayout, QtWidgets.QHBoxLayout))
-        else add_widget_function
+        else layout.addWidget
     )
 
 
@@ -420,26 +436,31 @@ def grid_layout(
     return layout
 
 
+T = TypeVar("T", QtWidgets.QVBoxLayout, QtWidgets.QHBoxLayout)
+
+
 def box_layout(
-    *widgets: QtWidgets.QWidget,
+    *widgets: WIDGET_OR_LAYOUT,
     parent: Optional[QtWidgets.QWidget] = None,
-    LayoutClass: type,
-) -> QtWidgets.QVBoxLayout:
+    LayoutClass: Type[T],
+) -> T:
     parent_args = () if parent is None else (parent,)
-    layout: QtWidgets.QVBoxLayout = LayoutClass(*parent_args)
+    layout = LayoutClass(*parent_args)
     for widget in widgets:
-        add_method = layout_add(layout, widget)
+        add_method = layout_add(layout=layout, child=widget)
         add_method(widget)
     return layout
 
 
 def vbox_layout(
-    *widgets: QtWidgets.QWidget, parent: Optional[QtWidgets.QWidget] = None
+    *widgets: WIDGET_OR_LAYOUT,
+    parent: Optional[QtWidgets.QWidget] = None,
 ) -> QtWidgets.QVBoxLayout:
     return box_layout(*widgets, parent=parent, LayoutClass=QtWidgets.QVBoxLayout)
 
 
 def hbox_layout(
-    *widgets: QtWidgets.QWidget, parent: Optional[QtWidgets.QWidget] = None
-) -> QtWidgets.QVBoxLayout:
+    *widgets: WIDGET_OR_LAYOUT,
+    parent: Optional[QtWidgets.QWidget] = None,
+) -> QtWidgets.QHBoxLayout:
     return box_layout(*widgets, parent=parent, LayoutClass=QtWidgets.QHBoxLayout)
