@@ -1,5 +1,4 @@
 from functools import partial
-from typing import Any
 
 from .component import (
     TabMixin,
@@ -11,16 +10,16 @@ from .component import (
 )
 from .file_selection_widget import ArchiveOnlyFileSelectionWidget
 from .pyside import QtCore, QtWidgets
+from .model import AppData
 from ..workflows import decrypt
 
 
 class DecryptTab(TabMixin):
     """Class that creates the "Decrypt" Tab of the GUI application."""
 
-    def __init__(self, *args: Any, **kwargs: Any):
-        super().__init__(*args, **kwargs)
-        self.app_data = self.parent().app_data
-
+    def __init__(self, parent: QtWidgets.QMainWindow, app_data: AppData):
+        super().__init__(parent=parent)
+        self.app_data = app_data
         files_panel = self.create_files_panel()
         decrypt_options_panel = self.create_decrypt_options_panel()
         self.create_run_panel("Decrypt data", self.decrypt, "Decrypt selected files")
@@ -42,7 +41,7 @@ class DecryptTab(TabMixin):
 
     def create_files_panel(self) -> QtWidgets.QGroupBox:
         box = ArchiveOnlyFileSelectionWidget(title="Files to decrypt", parent=self)
-        box.file_list_model.layoutChanged.connect(
+        box.file_list_model.layoutChanged.connect(  # type: ignore
             lambda: setattr(self.app_data, "decrypt_files", box.get_list())
         )
         return box
@@ -53,7 +52,7 @@ class DecryptTab(TabMixin):
         decompress = QtWidgets.QCheckBox("Decompress", box)
         decompress.setStatusTip("Decompress data after decryption")
         decompress.setChecked(not self.app_data.decrypt_decrypt_only)
-        decompress.stateChanged.connect(
+        decompress.stateChanged.connect(  # type: ignore
             lambda state: setattr(
                 self.app_data, "decrypt_decrypt_only", state == QtCore.Qt.Unchecked
             )
