@@ -1,5 +1,5 @@
 from functools import partial, wraps
-from typing import Any
+from typing import Any, cast
 
 from .component import (
     TabMixin,
@@ -17,7 +17,7 @@ from .component import (
     hbox_layout,
 )
 from .file_selection_widget import DirectoryAndFileSelectionWidget
-from .model import TableModel
+from .model import TableModel, AppData, KeyValueListModel
 from .pyside import QtCore, QtGui, QtWidgets
 from ..utils.config import LABEL_COMPRESSION_LEVEL, DESCRIPTION_COMPRESSION_LEVEL
 from ..core.metadata import Purpose
@@ -43,9 +43,9 @@ def encrypt_workflow(*args: str, **kwargs: Any) -> None:
 class EncryptTab(TabMixin):
     """Class that creates the "Encrypt" Tab of the GUI application."""
 
-    def __init__(self, *args: Any, **kwargs: Any):
-        super().__init__(*args, **kwargs)
-        self.app_data = self.parent().app_data
+    def __init__(self, parent: QtWidgets.QMainWindow, app_data: AppData):
+        super().__init__(parent=parent)
+        self.app_data = app_data
         files_panel = self.create_files_panel()
         self.create_run_panel(
             "Package and encrypt data", self.encrypt, "Package && Encrypt"
@@ -72,7 +72,7 @@ class EncryptTab(TabMixin):
 
     def create_files_panel(self) -> QtWidgets.QGroupBox:
         box = DirectoryAndFileSelectionWidget(title="Data to encrypt", parent=self)
-        box.file_list_model.layoutChanged.connect(
+        box.file_list_model.layoutChanged.connect(  # type: ignore
             lambda: setattr(self.app_data, "encrypt_files", box.get_list())
         )
         return box
@@ -118,10 +118,15 @@ class EncryptTab(TabMixin):
             )
 
         def update_recipients(index: QtCore.QModelIndex) -> None:
-            self.app_data.encrypt_recipients = [x[2] for x in index.model().get_data()]
+            # Note: it's probably possible to get rid of the cast() here.
+            recipients = cast(TableModel, index.model())
+            self.app_data.encrypt_recipients = tuple(
+                str(x[2]) for x in recipients.get_data()
+            )
 
         def add_recipient() -> None:
-            key = recipients_input_view.model().get_value(
+            # Note: it's probably possible to get rid of the cast() here.
+            key = cast(KeyValueListModel, recipients_input_view.model()).get_value(
                 recipients_input_view.currentIndex()
             )
             row = (key.uids[0].full_name, key.uids[0].email, key.fingerprint)
@@ -136,13 +141,12 @@ class EncryptTab(TabMixin):
             recipients_output_view.clearSelection()
 
         # Connect actions.
-        recipients_btn_add.clicked.connect(add_recipient)
-        recipients_btn_remove.clicked.connect(remove_recipient)
-        recipients_output_model.dataChanged.connect(update_recipients)
-        sender_widget.currentIndexChanged.connect(update_sender)
+        recipients_btn_add.clicked.connect(add_recipient)  # type: ignore
+        recipients_btn_remove.clicked.connect(remove_recipient)  # type: ignore
+        recipients_output_model.dataChanged.connect(update_recipients)  # type: ignore
+        sender_widget.currentIndexChanged.connect(update_sender)  # type: ignore
         # Set the default value for the sender
         update_sender(sender_widget.currentIndex())
-
         grid_layout(
             (
                 GridLayoutCell(
@@ -163,7 +167,7 @@ class EncryptTab(TabMixin):
         )
         return group_box
 
-    def _create_sender_transferinfo_and_output_layout(self) -> QtWidgets.QVBoxLayout:
+    def _create_sender_transferinfo_and_output_layout(self) -> QtWidgets.QHBoxLayout:
         """Create a layout with 3 group boxes: 'Data sender and recipients',
         'Data transfer info' and 'Output'.
         """
@@ -190,7 +194,7 @@ class EncryptTab(TabMixin):
         output_location.setStatusTip("Destination folder for the encrypted package")
 
         # Add actions
-        output_suffix.editingFinished.connect(
+        output_suffix.editingFinished.connect(  # type: ignore
             lambda: setattr(
                 self.app_data, "encrypt_package_name_suffix", output_suffix.text()
             )
@@ -219,14 +223,13 @@ class EncryptTab(TabMixin):
         ignore_disk_space_error.setChecked(
             self.app_data.encrypt_ignore_disk_space_error
         )
-        ignore_disk_space_error.stateChanged.connect(
+        ignore_disk_space_error.stateChanged.connect(  # type: ignore
             lambda state: setattr(
                 self.app_data,
                 "encrypt_ignore_disk_space_error",
                 state == QtCore.Qt.Checked,
             )
         )
-
         grid_layout(
             (QtWidgets.QLabel("Suffix"), output_suffix),
             (
@@ -248,7 +251,7 @@ class EncryptTab(TabMixin):
         # Create fields.
         transfer_id = LineEdit()
         transfer_id.setStatusTip("(optional) Data Transfer Request ID")
-        transfer_id.setValidator(QtGui.QIntValidator(1, 10 ** 9))
+        transfer_id.setValidator(QtGui.QIntValidator(1, 10**9))
         verify_dtr = create_verify_dtr_checkbox(
             self.app_data, "encrypt_verify_dtr", group_box
         )
@@ -261,8 +264,8 @@ class EncryptTab(TabMixin):
         def on_transfer_id_changed(text: str) -> None:
             self.app_data.encrypt_transfer_id = int(text) if text else None
 
-        transfer_id.textChanged.connect(on_transfer_id_changed)
-        purpose.currentTextChanged.connect(
+        transfer_id.textChanged.connect(on_transfer_id_changed)  # type: ignore
+        purpose.currentTextChanged.connect(  # type: ignore
             lambda text: setattr(
                 self.app_data, "encrypt_purpose", None if text == "" else Purpose(text)
             )
