@@ -1,6 +1,7 @@
 import html
 from pathlib import Path
 from typing import (
+    Iterable,
     Iterator,
     Optional,
     Sequence,
@@ -21,6 +22,7 @@ from .component import (
     grid_layout,
     GridLayoutCell,
 )
+from .model import AppData, KeyValueListModel
 from .keys_refresh import load_authority_key_threaded
 from .parallel import run_thread
 from .pyside import QtCore, QtGui, QtWidgets, QAction, open_window
@@ -34,9 +36,9 @@ from ..workflows import (
 
 
 class KeysTab(QtWidgets.QWidget):
-    def __init__(self, *args: Any, **kwargs: Any):
-        super().__init__(*args, **kwargs)
-        self.app_data = self.parent().app_data
+    def __init__(self, parent: QtWidgets.QMainWindow, app_data: AppData):
+        super().__init__(parent=parent)
+        self.app_data = app_data
 
         # Update public and private key lists in AppData.
         self.update_private_keys()
@@ -55,23 +57,23 @@ class KeysTab(QtWidgets.QWidget):
 
         self.priv_keys_view = QtWidgets.QListView()
         self.priv_keys_view.setModel(self.app_data.priv_keys_model)
-        self.priv_keys_view.selectionModel().currentChanged.connect(
+        self.priv_keys_view.selectionModel().currentChanged.connect(  # type: ignore
             self._update_display
         )
 
         self.pub_keys_view = QtWidgets.QListView()
         self.pub_keys_view.setModel(self.app_data.pub_keys_model)
-        self.pub_keys_view.selectionModel().currentChanged.connect(self._update_display)
+        self.pub_keys_view.selectionModel().currentChanged.connect(self._update_display)  # type: ignore
         self.pub_keys_view.setSelectionMode(
             QtWidgets.QAbstractItemView.ExtendedSelection
         )
 
         # When item is selected in the public/private key list, clear
         # the selection in the other list.
-        self.priv_keys_view.selectionModel().currentChanged.connect(
+        self.priv_keys_view.selectionModel().currentChanged.connect(  # type: ignore
             lambda: self.pub_keys_view.selectionModel().clear()
         )
-        self.pub_keys_view.selectionModel().currentChanged.connect(
+        self.pub_keys_view.selectionModel().currentChanged.connect(  # type: ignore
             lambda: self.priv_keys_view.selectionModel().clear()
         )
 
@@ -80,7 +82,7 @@ class KeysTab(QtWidgets.QWidget):
             "Generate new private/public key",
             self,
         )
-        action_generate_key.triggered.connect(lambda: KeyGenDialog(parent=self).show())
+        action_generate_key.triggered.connect(lambda: KeyGenDialog(parent=self).show())  # type: ignore
         action_refresh_keys = QAction(
             QtGui.QIcon(":icon/feather/refresh-cw.png"),
             "Refresh keys from the local keyring",
@@ -92,7 +94,7 @@ class KeysTab(QtWidgets.QWidget):
             self.update_public_keys()
             self.update_display_selected_pub_key()
 
-        action_refresh_keys.triggered.connect(refresh_keys)
+        action_refresh_keys.triggered.connect(refresh_keys)  # type: ignore
 
         toolbar = ToolBar("Key management", self)
         toolbar.addAction(action_generate_key)
@@ -206,8 +208,8 @@ class KeysTab(QtWidgets.QWidget):
 
         # Create a dict of actions (functions) to associate to each
         # action button of the GUI.
-        # The reason to create a dict object before looping over it is so that
-        # mypy gets the correct typing information (for some reason
+        # The reason to create a dict object before looping over it is so
+        # that mypy gets the correct typing information (for some reason
         # SelectionAction is not recognized as a subtype of QAction).
         functions_by_action: Sequence[Tuple[QAction, Callable[..., Any]]] = (
             (
@@ -249,7 +251,7 @@ class KeysTab(QtWidgets.QWidget):
             ),
         )
         for action, fn in functions_by_action:
-            action.triggered.connect(fn)
+            action.triggered.connect(fn)  # type: ignore
             yield action
 
     def update_private_keys(self) -> None:
@@ -269,29 +271,23 @@ class KeysTab(QtWidgets.QWidget):
             self.app_data.encrypt_sender = default_key
         except StopIteration:
             pass
-        self.app_data.priv_keys_model.set_data(
-            {f"{key.uids[0]} {key.key_id}": key for key in keys_private}
-        )
+        self.app_data.priv_keys_model.set_data(data=keys_as_tuple(keys=keys_private))
 
     def update_public_keys(self) -> None:
         """Retrieve/reload all public keys from the user's local keyring and
         store them in the application's memory."""
         keys_public = self.app_data.config.gpg_store.list_pub_keys(sigs=True)
-        self.app_data.pub_keys_model.set_data(
-            {f"{key.uids[0]} {key.key_id}": key for key in keys_public}
-        )
+        self.app_data.pub_keys_model.set_data(data=keys_as_tuple(keys=keys_public))
 
     def get_selected_keys(self) -> Tuple[gpg.Key, ...]:
         """Returns the gpg.Key objects corresponding to the keys currently
         selected in the GUI.
         """
-        # NOTE: cast() is needed here as selectedIndexes() wrongly hints that
-        #       it returns List[int] when in fact it returns
-        #       Sequence[QtCore.QModelIndex].
-        selected_indexes = (
-            cast(QtCore.QModelIndex, x) for x in self.pub_keys_view.selectedIndexes()
+        # Note: it's probably possible to get rid of the cast() here.
+        selected_keys = (
+            cast(KeyValueListModel, index.model()).get_value(index)
+            for index in self.pub_keys_view.selectedIndexes()
         )
-        selected_keys = (index.model().get_value(index) for index in selected_indexes)
         return tuple(selected_keys)
 
     def update_keys(self) -> None:
@@ -428,8 +424,12 @@ class KeysTab(QtWidgets.QWidget):
         )
         if index.isValid():
             try:
+                # Note: it's probably possible to get rid of the cast() here.
                 self.text_panel.setHtml(
-                    style + self.key_to_html(index.model().get_value(index))
+                    style
+                    + self.key_to_html(
+                        cast(KeyValueListModel, index.model()).get_value(index)
+                    )
                 )
             except IndexError:
                 self.text_panel.setHtml("")
@@ -440,16 +440,17 @@ class KeysTab(QtWidgets.QWidget):
 
 
 class KeyDownloadDialog(QtWidgets.QDialog):
-    def __init__(self, *args: Any, **kwargs: Any):
-        super().__init__(*args, **kwargs)
+    def __init__(self, parent: KeysTab):
+        super().__init__(parent=parent)
+        self.parent_tab = parent
         self.setWindowTitle("Download public keys from keyserver")
-        self.setWindowFlags(self.windowFlags() & ~QtCore.Qt.WindowContextHelpButtonHint)  # type: ignore
+        self.setWindowFlags(self.windowFlags() & ~QtCore.Qt.WindowContextHelpButtonHint)
 
         self.search_string = LineEdit()
         self.btn_search = QtWidgets.QPushButton("Search")
-        self.btn_search.clicked.connect(self.search_keys)
+        self.btn_search.clicked.connect(self.search_keys)  # type: ignore
         self.btn_search.setEnabled(False)
-        self.search_string.textChanged.connect(
+        self.search_string.textChanged.connect(  # type: ignore
             lambda text: self.btn_search.setEnabled(bool(text))
         )
 
@@ -463,13 +464,13 @@ class KeyDownloadDialog(QtWidgets.QDialog):
         self.btn_download = SelectionButton(
             "Download", self.key_list_view.selectionModel()
         )
-        self.btn_download.clicked.connect(self.download_selected)
+        self.btn_download.clicked.connect(self.download_selected)  # type: ignore
 
         self.label_results = QtWidgets.QLabel("")
         self.set_number_of_keys_found(None)
 
         btn_box = QtWidgets.QDialogButtonBox(QtWidgets.QDialogButtonBox.Close)
-        btn_box.rejected.connect(self.reject)
+        btn_box.rejected.connect(self.reject)  # type: ignore
 
         self.setLayout(
             grid_layout(
@@ -492,22 +493,24 @@ class KeyDownloadDialog(QtWidgets.QDialog):
     def search_keys(self) -> None:
         self.btn_search.setEnabled(False)
         self.key_list_view.selectionModel().clear()
-        self.key_list_view.model().setStringList([])
+
+        # Note: using cast() here as self.key_list_view.model() seems to have
+        # a bad return value type-hint.
+        key_list_model = cast(QtCore.QStringListModel, self.key_list_view.model())
+        key_list_model.setStringList([])
         self.set_number_of_keys_found(None)
 
         def on_result(keys: Sequence[gpg.KeyInfo]) -> None:
-            self.key_list_view.model().setStringList(
-                [f"{k.uid} {k.fingerprint}" for k in keys]
-            )
+            key_list_model.setStringList([f"{k.uid} {k.fingerprint}" for k in keys])
             self.set_number_of_keys_found(len(keys))
 
         run_thread(
             crypt.search_keyserver,
             f_kwargs=dict(
                 search_term=self.search_string.text(),
-                keyserver=self.parent().app_data.config.keyserver_url,
+                keyserver=self.parent_tab.app_data.config.keyserver_url,
             ),
-            report_config=self.parent().app_data.config,
+            report_config=self.parent_tab.app_data.config,
             forward_errors=warning_callback("GPG key search error"),
             signals=dict(result=on_result),
         )
@@ -516,28 +519,24 @@ class KeyDownloadDialog(QtWidgets.QDialog):
         """Download keys selected in the key-search pop-up to the user's
         local keyring.
         """
-        # NOTE: cast() is needed here as selectedIndexes() wrongly hints that
-        #       it returns List[int] when in fact it returns
-        #       Sequence[QtCore.QModelIndex].
-        selected_indexes = (
-            cast(QtCore.QModelIndex, x) for x in self.key_list_view.selectedIndexes()
-        )
-        keys_to_download = [index.model().data(index) for index in selected_indexes]
+        keys_to_download = [
+            index.model().data(index) for index in self.key_list_view.selectedIndexes()
+        ]
         if keys_to_download:
 
             def on_result() -> None:
-                self.parent().update_public_keys()
-                self.parent().update_display_selected_pub_key()
+                self.parent_tab.update_public_keys()
+                self.parent_tab.update_display_selected_pub_key()
 
             self.btn_download.setEnabled(False)
             run_thread(
                 crypt.download_keys,
                 f_kwargs=dict(
                     fingerprints=[x.split()[-1] for x in keys_to_download],
-                    keyserver=self.parent().app_data.config.keyserver_url,
-                    gpg_store=self.parent().app_data.config.gpg_store,
+                    keyserver=self.parent_tab.app_data.config.keyserver_url,
+                    gpg_store=self.parent_tab.app_data.config.gpg_store,
                 ),
-                report_config=self.parent().app_data.config,
+                report_config=self.parent_tab.app_data.config,
                 forward_errors=warning_callback("GPG key search error"),
                 signals=dict(
                     result=on_result,
@@ -547,10 +546,11 @@ class KeyDownloadDialog(QtWidgets.QDialog):
 
 
 class KeyGenDialog(QtWidgets.QDialog):
-    def __init__(self, *args: Any, **kwargs: Any):
-        super().__init__(*args, **kwargs)
+    def __init__(self, parent: KeysTab):
+        super().__init__(parent=parent)
+        self.parent_tab = parent
         self.setWindowTitle("Generate new key pair")
-        self.setWindowFlags(self.windowFlags() & ~QtCore.Qt.WindowContextHelpButtonHint)  # type: ignore
+        self.setWindowFlags(self.windowFlags() & ~QtCore.Qt.WindowContextHelpButtonHint)
 
         self.text_name_full = LineEdit()
         self.text_name_extra = LineEdit()
@@ -564,12 +564,12 @@ class KeyGenDialog(QtWidgets.QDialog):
 
         self.btn_run = QtWidgets.QPushButton("Generate key")
         self.btn_run.setDefault(True)
-        self.btn_run.clicked.connect(self.create_private_key)
+        self.btn_run.clicked.connect(self.create_private_key)  # type: ignore
         btn_cancel = QtWidgets.QPushButton("Close")
-        btn_cancel.clicked.connect(self.close)
+        btn_cancel.clicked.connect(self.close)  # type: ignore
         btn_show_pass = QtWidgets.QPushButton("Show")
         btn_show_pass.setCheckable(True)
-        btn_show_pass.clicked.connect(self.toggle_password_visibility)
+        btn_show_pass.clicked.connect(self.toggle_password_visibility)  # type: ignore
 
         self.setLayout(
             grid_layout(
@@ -615,7 +615,7 @@ class KeyGenDialog(QtWidgets.QDialog):
             revocation_cert = crypt.create_revocation_certificate(
                 key.fingerprint,
                 self.text_pass.text(),
-                self.parent().app_data.config.gpg_store,
+                self.parent_tab.app_data.config.gpg_store,
             )
             msg.setText(
                 "Your new key has been successfully generated.\n\n"
@@ -626,7 +626,7 @@ class KeyGenDialog(QtWidgets.QDialog):
                 "location, as anyone can use it to revoke your key."
             )
             msg.setDetailedText(revocation_cert.decode())
-            # Programatically click the "Show Details..." button so that the
+            # Programmatically click the "Show Details..." button so that the
             # certificate is shown by default.
             click_show_details(msgbox=msg)
 
@@ -641,13 +641,13 @@ class KeyGenDialog(QtWidgets.QDialog):
         finally:
             open_window(msg)
             if (
-                self.parent().app_data.config.key_authority_fingerprint
-                and not self.parent().app_data.config.offline
+                self.parent_tab.app_data.config.key_authority_fingerprint
+                and not self.parent_tab.app_data.config.offline
             ):
-                request_signature((key,), self.parent().app_data.config, self)
+                request_signature((key,), self.parent_tab.app_data.config, self)
             self.clear_form()
-            self.parent().update_private_keys()
-            self.parent().update_public_keys()
+            self.parent_tab.update_private_keys()
+            self.parent_tab.update_public_keys()
             self.close()
 
     def create_private_key(self) -> None:
@@ -673,10 +673,10 @@ class KeyGenDialog(QtWidgets.QDialog):
                 full_name=name_full,
                 email=self.text_email.text(),
                 pwd=Secret(self.text_pass.text()),
-                gpg_store=self.parent().app_data.config.gpg_store,
+                gpg_store=self.parent_tab.app_data.config.gpg_store,
             ),
             forward_errors=warning_callback("GPG Key Generation Error"),
-            report_config=self.parent().app_data.config,
+            report_config=self.parent_tab.app_data.config,
             signals=dict(
                 result=self.post_key_creation,
                 finished=lambda: self.btn_run.setEnabled(True),
@@ -736,3 +736,8 @@ def ok_message(
     msg_ok.setWindowTitle(title)
     msg_ok.setText(msg)
     return lambda: open_window(msg_ok)
+
+
+def keys_as_tuple(keys: Sequence[gpg.Key]) -> Iterable[Tuple[str, gpg.Key]]:
+    """Returns a generator of tuples of the form ("userID keyID", key)."""
+    return ((f"{key.uids[0]} {key.key_id}", key) for key in keys)
