@@ -14,17 +14,18 @@ from typing import (
     cast,
 )
 
-from libbiomedit.lib.secret import Secret
-
 
 from .pyside import QtCore
-from .ui_model_bind import ClassWithListener
+from .listener import ClassWithListener
 from ..core import gpg
 from ..core.metadata import Purpose
+from ..core.secret import Secret
 from ..utils.config import Config
-from ..protocols import Protocol, sftp, liquid_files
+from ..protocols import Protocol, sftp, liquid_files, s3
 from .listener import ListenerWrap
 
+INDEX_UNION_TYPE = Union[QtCore.QModelIndex, QtCore.QPersistentModelIndex]
+
 # Default value Qt.DisplayRole for index is not an int (upstream issue).
 default_display_role = cast(int, QtCore.Qt.DisplayRole)
 
@@ -52,16 +53,16 @@ class TableModel(QtCore.QAbstractTableModel):
 
     def set_data(self, data: Sequence[Sequence[Any]]) -> None:
         self._data = tuple(sorted(tuple(x) for x in data))
-        self.layoutChanged.emit()
-        self.dataChanged.emit(
+        self.layoutChanged.emit()  # type: ignore
+        self.dataChanged.emit(  # type: ignore
             self.createIndex(0, 0),
             self.createIndex(self.rowCount(), self.columnCount()),
         )
 
-    def rowCount(self, _parent: QtCore.QModelIndex = QtCore.QModelIndex()) -> int:
+    def rowCount(self, _parent: INDEX_UNION_TYPE = QtCore.QModelIndex()) -> int:
         return len(self._data)
 
-    def columnCount(self, _parent: QtCore.QModelIndex = QtCore.QModelIndex()) -> int:
+    def columnCount(self, _parent: INDEX_UNION_TYPE = QtCore.QModelIndex()) -> int:
         return len(self._data) and len(self._data[0])
 
     def headerData(
@@ -77,14 +78,14 @@ class TableModel(QtCore.QAbstractTableModel):
         return None
 
     def data(
-        self, index: QtCore.QModelIndex, role: int = default_display_role
+        self, index: INDEX_UNION_TYPE, role: int = default_display_role
     ) -> Optional[Any]:
         if role == default_display_role:
             return self._data[index.row()][index.column()]
         return None
 
     def removeRows(
-        self, row: int, count: int, _parent: QtCore.QModelIndex = QtCore.QModelIndex()
+        self, row: int, count: int, _parent: INDEX_UNION_TYPE = QtCore.QModelIndex()
     ) -> bool:
         if row > -1 and row + count <= self.rowCount():
             self.beginRemoveRows(QtCore.QModelIndex(), row, row + count - 1)
@@ -109,7 +110,7 @@ class KeyValueListModel(QtCore.QAbstractListModel):
     def set_data(self, data: Iterable[Tuple[Hashable, Any]]) -> None:
         self._keyvalues = dict(data)
         self._keys = list(self._keyvalues.keys())
-        self.layoutChanged.emit()
+        self.layoutChanged.emit()  # type: ignore
 
     # Default value Qt.DisplayRole for index is not an int (upstream issue):
     def data(self, index, role) -> Optional[Hashable]:  # type: ignore
@@ -118,7 +119,7 @@ class KeyValueListModel(QtCore.QAbstractListModel):
             return key
         return None
 
-    def rowCount(self, _parent: QtCore.QModelIndex = QtCore.QModelIndex()) -> int:
+    def rowCount(self, _parent: INDEX_UNION_TYPE = QtCore.QModelIndex()) -> int:
         return len(self._keys)
 
     def get_value(self, index: Union[int, QtCore.QModelIndex]) -> Any:
@@ -132,6 +133,7 @@ class KeyValueListModel(QtCore.QAbstractListModel):
 def protocol_factory() -> Dict[Type[Protocol], ListenerWrap]:
     return {
         sftp.Protocol: ListenerWrap(new_sftp_connection()),
+        s3.Protocol: ListenerWrap(new_s3_connection()),
         liquid_files.Protocol: ListenerWrap(new_liquid_files_connection()),
     }
 
@@ -140,6 +142,10 @@ def new_sftp_connection() -> Protocol:
     return sftp.Protocol(host="", username="", destination_dir="")
 
 
+def new_s3_connection() -> Protocol:
+    return s3.Protocol(host="", bucket="", access_key="", secret_key=Secret(""))
+
+
 def new_liquid_files_connection() -> Protocol:
     return liquid_files.Protocol(host="", api_key=Secret(""))
 
@@ -150,9 +156,9 @@ class AppData(ClassWithListener):
 
     config: Config
 
-    encrypt_sender: str = ""
+    encrypt_sender: Optional[str] = None
     encrypt_recipients: Tuple[str, ...] = ()
-    encrypt_transfer_id: Optional[str] = None
+    encrypt_transfer_id: Optional[int] = None
     encrypt_purpose: Optional[Purpose] = None
     encrypt_compression_level: int = 6
     encrypt_output_location: Path = field(default_factory=Path.home)
