@@ -1,5 +1,5 @@
 import os
-from typing import Optional, Any
+from typing import Optional, Union, Any
 
 try:
     if os.environ.get("SETT_LEGACY", "") == "true":
@@ -15,7 +15,9 @@ try:
     QtWidgets = _QtWidgets
     QAction = _QAction
 
-    def open_window(window: QtWidgets.QWidget) -> Any:
+    def open_window(
+        window: Union[QtWidgets.QApplication, QtWidgets.QMessageBox, QtWidgets.QDialog]
+    ) -> Any:
         return window.exec()
 
     def get_application_global_instance() -> Optional[QtCore.QCoreApplication]:
@@ -34,7 +36,9 @@ except ImportError:
     QtWidgets = _QtWidgets_PySide2  # type: ignore
     QAction = _QAction_PySide2  # type: ignore
 
-    def open_window(window: QtWidgets.QWidget) -> Any:
+    def open_window(
+        window: Union[QtWidgets.QApplication, QtWidgets.QMessageBox, QtWidgets.QDialog]
+    ) -> Any:
         return window.exec_()
 
     def get_application_global_instance() -> Optional[QtCore.QCoreApplication]:
