@@ -1,4 +1,4 @@
-from typing import Optional, Tuple, Union, Dict, Callable, Sequence, Any
+from typing import Optional, Tuple, Union, Dict, Callable, Sequence, Any, cast
 from dataclasses import Field, asdict, fields  # pylint: disable=unused-import
 
 from .listener import Listener
@@ -17,6 +17,7 @@ from .component import (
     grid_layout,
     GridLayoutCell,
 )
+from .model import AppData
 from .pyside import QtCore, QtGui, QtWidgets
 from .keys_refresh import load_authority_key_threaded
 from ..utils import config
@@ -26,13 +27,13 @@ from ..utils.config import Config, FileType
 class ConfigProxy(Listener):
     """Proxy between the Config dataclass and the UI."""
 
-    def __init__(self, parent: QtWidgets.QWidget):
-        self._parent = parent
+    def __init__(self, app_data: AppData):
         super().__init__()
+        self.app_data = app_data
 
     def set_value(self, attr: str, val: Any) -> None:
         """Updates the specified sett config attribute (attr) with a new value."""
-        cfg = self._parent.config
+        cfg = self.app_data.config
         if val != getattr(cfg, attr):
             setattr(cfg, attr, val)
             if attr == "key_authority_fingerprint":
@@ -40,12 +41,12 @@ class ConfigProxy(Listener):
                 # a proper fingerprint was entered. Otherwise we get a warning
                 # each time the user is entering a new character in the field.
                 if len(val) == 40:
-                    load_authority_key_threaded(self._parent)
+                    load_authority_key_threaded(self.app_data)
                 else:
-                    self._parent.validation_authority_key = None
+                    self.app_data.validation_authority_key = None
 
     def get_value(self, attr: str) -> Any:
-        return getattr(self._parent.config, attr)
+        return getattr(self.app_data.config, attr)
 
     def refresh(self) -> None:
         for callbacks in self._listeners.values():
@@ -56,27 +57,27 @@ class ConfigProxy(Listener):
         """Sets/Updates the in-memory config values with the new values passed
         in "cfg". Then updates the Settings Tab widgets in the UI.
         """
-        self._parent.config = cfg
+        self.app_data.config = cfg
         self.refresh()
 
     def get_config(self) -> Config:
         """Returns the current in-memory config values."""
-        cfg: Config = self._parent.config
+        cfg: Config = self.app_data.config
         return cfg
 
 
 class SettingsTab(QtWidgets.QWidget):
     persist_btn_text = "Save to config file"
 
-    def __init__(self, *args: Any, **kwargs: Any):
-        super().__init__(*args, **kwargs)
-        self.parent_widget = self.parent()
-        self.config_proxy = ConfigProxy(self.parent_widget.app_data)
+    def __init__(self, parent: QtWidgets.QMainWindow, app_data: AppData):
+        super().__init__(parent=parent)
+        self.app_data = app_data
+        self.config_proxy = ConfigProxy(self.app_data)
 
         widget_register: Dict[str, QtWidgets.QWidget] = {}
         cfg_fields = {f.name: f for f in fields(Config)}
 
-        def cfg_field(key: str) -> Tuple[QtWidgets.QLabel, ...]:
+        def cfg_field(key: str) -> Tuple[QtWidgets.QWidget, ...]:
             return widget_row_from_field(
                 self.config_proxy, cfg_fields[key], widget_register=widget_register
             )
@@ -123,10 +124,14 @@ class SettingsTab(QtWidgets.QWidget):
         )
         # Enable or disable the PGP key auto-download checkbox option based on
         # whether a keyserver URL value is provided or not.
-        self.checkbox_gpg_key_autodownload = widget_register["gpg_key_autodownload"]
-        self.field_keyserver_url = widget_register["keyserver_url"]
+        self.checkbox_gpg_key_autodownload = cast(
+            QtWidgets.QCheckBox, widget_register["gpg_key_autodownload"]
+        )
+        self.field_keyserver_url = cast(
+            QtWidgets.QLineEdit, widget_register["keyserver_url"]
+        )
         self._enable_checkbox_key_autodownload()
-        self.field_keyserver_url.textChanged.connect(
+        self.field_keyserver_url.textChanged.connect(  # type: ignore
             self._enable_checkbox_key_autodownload
         )
         self.config_proxy.refresh()
@@ -146,13 +151,13 @@ class SettingsTab(QtWidgets.QWidget):
         top_label.setWordWrap(True)
         reset_btn = QtWidgets.QPushButton("Reset", self)
         reset_btn.setStatusTip("Resets to your last persisted settings")
-        reset_btn.clicked.connect(
+        reset_btn.clicked.connect(  # type: ignore
             lambda: self.config_proxy.set_config(config.load_config())
         )
 
         defaults_btn = QtWidgets.QPushButton("Restore defaults", self)
         defaults_btn.setStatusTip("Reset all settings to their default values")
-        defaults_btn.clicked.connect(
+        defaults_btn.clicked.connect(  # type: ignore
             lambda: self.config_proxy.set_config(config.default_config())
         )
         return (GridLayoutCell(top_label, span=2), reset_btn, defaults_btn)
@@ -161,7 +166,7 @@ class SettingsTab(QtWidgets.QWidget):
         persist_btn = QtWidgets.QPushButton(self.persist_btn_text, self)
         persist_btn.setIcon(QtGui.QIcon(":icon/feather/save.png"))
         persist_btn.setStatusTip("Saves your current settings to the config file")
-        persist_btn.clicked.connect(self._save_config_to_disk)
+        persist_btn.clicked.connect(self._save_config_to_disk)  # type: ignore
         return (GridLayoutCell(persist_btn, span=4),)
 
     def _enable_checkbox_key_autodownload(self) -> None:
@@ -270,9 +275,9 @@ def widget_row_from_field(
     config_proxy: ConfigProxy,
     field: "Field[Any]",
     widget_register: Optional[Dict[str, QtWidgets.QWidget]] = None,
-) -> Tuple[QtWidgets.QLabel, ...]:
+) -> Tuple[QtWidgets.QWidget, ...]:
     """Create a widget row consisting of a label, a main widget and possible
-    aux widgets based on field metadata of the Config dataclass.
+    auxiliary widgets based on field metadata of the Config dataclass.
 
     If widget_register is passed, register the main widget under the
     corresponding field name.
