@@ -1,9 +1,14 @@
 import mimetypes
 import uuid
-from typing import Tuple
+from typing import Tuple, Union, Iterable
 
 
-def encode(name: str, filename: str, data: bytes, extra_data=()) -> Tuple[str, bytes]:
+def encode(
+    name: str,
+    filename: str,
+    data: bytes,
+    extra_data: Iterable[Tuple[str, Union[str, int]]] = (),
+) -> Tuple[str, bytes]:
     boundary = uuid.uuid4().hex
     content_type = f"multipart/form-data; boundary={boundary}"
     boundary_b = boundary.encode()
@@ -31,7 +36,7 @@ def encode(name: str, filename: str, data: bytes, extra_data=()) -> Tuple[str, b
     )
 
 
-def encode_value(key: str, value) -> bytes:
+def encode_value(key: str, value: Union[str, int]) -> bytes:
     return (
         b'Content-Disposition: form-data; name="' + key.encode() + b'"\r\n'
         b"\r\n" + str(value).encode() + b"\r\n"
