@@ -5,7 +5,7 @@ import platform
 import warnings
 from dataclasses import dataclass, field as _field, fields
 from pathlib import Path
-from typing import Dict, Optional, Callable, Union, cast, Any
+from typing import Dict, Optional, Callable, Union, Any
 
 from libbiomedit.lib import deserialize as serialization
 
@@ -185,7 +185,8 @@ class Config:
     log_max_file_number: int = field_ext(
         default=1000,
         label="Log max. file number",
-        description="Maximum number of logfiles to keep as backup. Set to 0 to disable logging.",
+        description="Maximum number of log files to keep as backup. "
+        "Set to 0 to disable logging.",
         minimum=0,
     )
     connections: Dict[str, Protocol] = field_ext(
@@ -234,7 +235,8 @@ class Config:
     max_cpu: int = field_ext(
         default=0,
         label="Max CPU",
-        description="Maximum number of CPU cores for parallel computation (use all CPU cores if value equals 0)",
+        description="Maximum number of CPU cores for parallel computation "
+        "(use all CPU cores if value equals 0)",
         minimum=0,
         maximum=os.cpu_count()
         or 4,  # In case cpu_count fails to detect the number of available cores
@@ -243,7 +245,8 @@ class Config:
     gpg_key_autodownload: bool = field_ext(
         default=True,
         label="Allow PGP key auto-download",
-        description="Allow the automatic download and refresh of PGP keys from the Keyserver.",
+        description="Allow the automatic download and refresh of PGP keys "
+        "from the Keyserver.",
     )
 
     verify_package_name: bool = field_ext(
@@ -432,7 +435,7 @@ def open_gpg_dir(gpg_dir: str) -> gpg.GPGStore:
 
 
 def migrate_user_config_file() -> None:
-    """Temporary migration to auto-update user's config files after arguments
+    """Temporary migrations to auto-update a user's config file after arguments
     are modified or deprecated in sett.
     """
     config_file = get_config_file()
@@ -443,31 +446,7 @@ def migrate_user_config_file() -> None:
     except UserError:
         return
 
-    # Migrations to auto-update user's config files after changes from
-    # https://gitlab.com/biomedit/sett/-/merge_requests/56
-    # Migrations added in June 2021, can be removed after about a year.
-    if "gpg_config_dir" in config_dict:
-        config_dict["gpg_home_dir"] = config_dict.pop("gpg_config_dir")
-        config_needs_update = True
-
-    if "key_validation_authority_keyid" in config_dict:
-        fingerprint = cast(str, Config().key_authority_fingerprint)
-        key_id = config_dict.pop("key_validation_authority_keyid")
-        if key_id == fingerprint[-16:]:
-            config_dict["key_authority_fingerprint"] = fingerprint
-        else:
-            config_dict["key_authority_fingerprint"] = key_id
-            warnings.warn(
-                f"This new version of {APP_NAME_SHORT} requires the full "
-                "fingerprint of the key validation authority. Please update "
-                "the 'key_authority_fingerprint' field in your config file: "
-                f"{config_file}"
-            )
-
-        config_needs_update = True
-
-    # Remove "temp_dir" from config. This is done here rather than in its
-    # own migration function to avoid loading/writing the config file twice.
+    # Migration to remove "temp_dir" from config.
     # Migration added in July 2021, can be removed after about a year.
     if "temp_dir" in config_dict:
         del config_dict["temp_dir"]
