@@ -19,7 +19,13 @@ from typing import (
     TypeVar,
 )
 
-import colorama  # type: ignore
+try:
+    import colorama  # type: ignore
+
+    colorama.init()
+except ImportError:
+    colorama = None
+
 
 from .. import RUNTIME_INFO
 
@@ -27,8 +33,6 @@ LOG_FORMAT = "[%(levelname)s] %(message)s"
 LOG_FORMAT_WITH_EMOJI = "%(levelname)s  %(message)s"
 LOG_FORMAT_WITH_TIME_AND_PID = "[%(asctime)s] [PID:%(process)d] " + LOG_FORMAT
 
-colorama.init()
-
 
 class EmojiLevelFormatter(logging.Formatter):
     log_style = {
@@ -51,18 +55,29 @@ class EmojiLevelFormatter(logging.Formatter):
         return super().format(record)
 
 
-class ColoredTerminalFormatter(logging.Formatter):
-    log_style = {
-        logging.WARNING: colorama.Fore.YELLOW,
-        logging.ERROR: colorama.Fore.RED,
-        logging.CRITICAL: colorama.Fore.RED,
-    }
+terminal_formatter: logging.Formatter
+if platform.system() == "Windows":
+    if colorama is None:
+        # Windows terminal does not support emojis, so EmojiLevelFormatter cannot be used.
+        terminal_formatter = logging.Formatter(LOG_FORMAT)
+    else:
 
-    def format(self, record: logging.LogRecord) -> str:
-        color = self.log_style.get(record.levelno)
-        if color:
-            return f"{color}{super().format(record)}{colorama.Fore.RESET}"
-        return super().format(record)
+        class ColoredTerminalFormatter(logging.Formatter):
+            log_style = {
+                logging.WARNING: colorama.Fore.YELLOW,
+                logging.ERROR: colorama.Fore.RED,
+                logging.CRITICAL: colorama.Fore.RED,
+            }
+
+            def format(self, record: logging.LogRecord) -> str:
+                color = self.log_style.get(record.levelno)
+                if color:
+                    return f"{color}{super().format(record)}{colorama.Fore.RESET}"
+                return super().format(record)
+
+        terminal_formatter = ColoredTerminalFormatter(LOG_FORMAT)
+else:
+    terminal_formatter = EmojiLevelFormatter(LOG_FORMAT_WITH_EMOJI)
 
 
 @contextmanager
@@ -258,11 +273,7 @@ def log_to_stream(
     if logger is None:
         logger = logging.getLogger()
     console_handler = logging.StreamHandler()
-    console_handler.setFormatter(
-        ColoredTerminalFormatter(LOG_FORMAT)
-        if platform.system() == "Windows"
-        else EmojiLevelFormatter(LOG_FORMAT_WITH_EMOJI)
-    )
+    console_handler.setFormatter(terminal_formatter)
     console_handler.setLevel(logger_level)
     logger.addHandler(console_handler)
 
