@@ -1,6 +1,6 @@
-import json
 import os
 import re
+import json
 import time
 from typing import List, Tuple, Dict, Optional, Callable
 
@@ -45,14 +45,16 @@ def transfer(
     :param protocol: parameters that specify the protocol (e.g. sftp) and
         destination (e.g. server URL) to be used for the transfer.
     :param config: sett config file object.
-    :two_factor_callback: function to 2FA if the destination server requires
+    :param two_factor_callback: function to 2FA if the destination server requires
         it.
-    :dry_run: if True, tests on the data to be transferred are carried-out,
+    :param dry_run: if True, tests on the data to be transferred are carried-out,
         but the actual transfer of files is skipped.
     :param verify_dtr: if True, the Data Transfer ID indicated in the data
         package's metadata is checked to ensure the transfer is authorized.
         This feature requires that a central "data portal" is available (see
         config file).
+        If verify_dtr is set to 'None', DTR ID verification is conditional upon
+        the presence of a DTR ID in the metadata of the file(s) to transfer.
     :param verify_pkg_name: if True, a check on the name of the file(s) to be
         transferred to verify that it matches an expected pattern:
         <project_code>_<date_format>_<package_name_suffix>.zip
@@ -64,20 +66,21 @@ def transfer(
     :raises UserError:
     """
 
-    logger.info(
-        "File(s) to transfer: [%s]%s",
-        ", ".join(files),
-        " (dry_run)" if dry_run else "",
-    )
+    with logger.log_task(
+        f"Input data verification{' (dry_run)' if dry_run else ''}..."
+    ):
 
-    with logger.log_task("Input data check"):
+        logger.info("Files to transfer: %s", ", ".join(files))
+        files_by_recipient: Dict[Tuple[gpg.Key, ...], List[str]] = {}
+
+        # Loop through all files to transfer and verify their content.
         for archive_path in files:
+            logger.info("Verifying: %s", archive_path)
+
+            # Verify input data package extension and content.
             check_package(archive_path)
 
-    files_by_recipient: Dict[Tuple[gpg.Key, ...], List[str]] = {}
-    with logger.log_task("Extracting destination for each package"):
-        for archive_path in files:
-            logger.info("Processing: %s", archive_path)
+            # Verify input data package metadata.
             with extract_multiple(
                 archive_path, (METADATA_FILE, DATA_FILE_ENCRYPTED)
             ) as (
@@ -95,12 +98,18 @@ def transfer(
                     )
                 )
             metadata = load_metadata(raw_metadata)
+
+            # If DTR ID verification is not specifically enabled/disabled, then
+            # it is carried-out only if the metadata of the file to transfer
+            # contains a DTR ID value.
             if verify_dtr is None:
                 verify_dtr = metadata.transfer_id is not None
+
             if verify_dtr:
                 if metadata.transfer_id is None:
                     raise UserError(
-                        "DTR (Data Transfer Request) ID is missing in file metadata."
+                        "DTR (Data Transfer Request) ID verification was "
+                        "requested but DTR ID is missing in file metadata."
                     )
 
                 try:
@@ -127,19 +136,33 @@ def transfer(
         logger.info("Dry run completed successfully")
         return
 
-    for recipient_keys, r_files in files_by_recipient.items():
-        emails = [get_recipient_email(k) for k in recipient_keys]
-        if hasattr(protocol, "recipients"):
-            setattr(protocol, "recipients", emails)
-        if hasattr(protocol, "pkey_password_encoding"):
-            setattr(protocol, "pkey_password_encoding", config.ssh_password_encoding)
-        with logger.log_task(
-            "Transferring files encrypted for " f"{', '.join(emails)}"
-        ):
+    # Transfer files to their destination.
+    with logger.log_task("Transferring files..."):
+        # For efficiency, files for a same recipient/destination are
+        # transferred together.
+        for recipient_keys, r_files in files_by_recipient.items():
+            emails = [get_recipient_email(k) for k in recipient_keys]
+
+            # LiquidFiles protocol: email addresses of the recipient must be
+            # specified as part of the protocol.
+            if hasattr(protocol, "recipients"):
+                setattr(protocol, "recipients", emails)
+
+            # SFTP protocol: encoding of public SSH key must be specified.
+            if hasattr(protocol, "pkey_password_encoding"):
+                setattr(
+                    protocol, "pkey_password_encoding", config.ssh_password_encoding
+                )
+
+            logger.info("Transferring files encrypted for: %s", ", ".join(emails))
             protocol.upload(
-                r_files, progress=progress, two_factor_callback=two_factor_callback
+                files=r_files,
+                two_factor_callback=two_factor_callback,
+                progress=progress,
             )
 
+    logger.info("Completed data transfer")
+
 
 def check_archive_name_follows_convention(
     archive_path: str,
