@@ -14,8 +14,10 @@ logger = create_logger(__name__)
 
 
 @log_runtime_info(logger)
-def upload_keys(key_ids: Sequence[str], *, config: Config):
-    """Upload keys"""
+def upload_keys(key_ids: Sequence[str], *, config: Config) -> None:
+    """Upload one or more public PGP keys to the keyserver specified in the
+    config.
+    """
     if config.offline:
         raise UserError("Uploading keys is not possible in the offline mode.")
     if config.keyserver_url is None:
